% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plotAbundance.R
\name{plotAbundance}
\alias{plotAbundance}
\alias{plotAbundance,SummarizedExperiment-method}
\title{Plotting abundance data}
\usage{
plotAbundance(x, ...)

\S4method{plotAbundance}{SummarizedExperiment}(
  x,
  rank = taxonomyRanks(x)[1],
  features = NULL,
  order_rank_by = c("name", "abund", "revabund"),
  order_sample_by = NULL,
  decreasing = TRUE,
  use_relative = TRUE,
  layout = c("bar", "point"),
  one_facet = TRUE,
  ncol = 2,
  scales = "fixed",
  abund_values = "counts",
  ...
)
}
\arguments{
\item{x}{a
\code{\link[SummarizedExperiment:SummarizedExperiment-class]{SummarizedExperiment}}
object.}

\item{...}{additional parameters for plotting. See
\code{\link{mia-plot-args}} for more details}

\item{rank}{a single \code{character} value defining the taxonomic rank to
use. Must be a value of \code{taxonomyRanks(x)}.}

\item{features}{data \code{colData} to be plotted below the abundance plot.
Continuous numeric values will be plotted as point, whereas factors and
character will be plotted as colour-code bar. (default: \code{features =
  NULL})}

\item{order_rank_by}{How to order abundance value: By name (\dQuote{name}),
by abundance (\dQuote{abund}) or by reverse abundance (\dQuote{revabund}).}

\item{order_sample_by}{A single character value from the chosen rank of abundance
data data or from \code{colData} to select values to order the abundance
plot by. If the value is not part of \code{features}, it will be added.
(default: \code{order_sample_by = NULL})}

\item{decreasing}{TRUE or FALSE: If the \code{order_sample_by} is defined and the
values are numeric, should the values used to order in decreasing or
increasing fashion? (default: \code{decreasing = FALSE})}

\item{use_relative}{\code{TRUE} or \code{FALSE}: Should the relative values
be calculated? (default: \code{use_relative = TRUE})}

\item{layout}{Either \dQuote{bar} or \dQuote{point}.}

\item{one_facet}{Should the plot be returned in on facet or split into
different facet, one facet per different value detect in \code{rank}. If
\code{features} or \code{order_sample_by} is not \code{NULL}, this setting will
be disregarded.}

\item{ncol, scales}{if \code{one_facet = FALSE}, \code{ncol} defines many
columns should be for plotting the different facets and \code{scales} is
used to define the behavior of the scales of each facet. Both values are
passed onto \code{\link[ggplot2:facet_wrap]{facet_wrap}}.}

\item{abund_values}{a \code{character} value defining which assay data to
use. (default: \code{abund_values = "relabundance"})}
}
\value{
a \code{\link[ggplot2:ggplot]{ggplot}} object or list of
\code{\link[ggplot2:ggplot]{ggplot}} objects, if \code{features} are added to
the plot.
}
\description{
\code{plotAbundance} plots the abundance on a selected taxonomic rank.
Since this probably makes sense only for relative abundance data, the
assay used by default is expected to be in the slot \sQuote{relabundance}.
}
\details{
Subsetting to rows of interested and ordering of those is expected to be done
outside of this functions, e.g. \code{x[1:2,]}. This will plot data of all
features present.
}
\examples{
data(GlobalPatterns, package="mia")
se <- GlobalPatterns

#
plotAbundance(se, abund_values="counts")
#
plotAbundance(se, abund_values="counts", rank = "Phylum", add_legend = FALSE)

# If rank is set to NULL plotAbundance behaves like plotExpression
plotAbundance(se, abund_values="counts", rank = NULL,
              features = head(rownames(se)))
              
# Factors can also be plotted and ordered by
plotAbundance(se, abund_values="counts", rank = "Phylum",
              features = "SampleType",
              order_sample_by = "SampleType")
}
