% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plotSeries.R
\name{plotSeries}
\alias{plotSeries}
\alias{plotSeries,SummarizedExperiment-method}
\title{Plot Series}
\usage{
plotSeries(
  object,
  x,
  y = NULL,
  rank = NULL,
  colour_by = NULL,
  size_by = NULL,
  linetype_by = NULL,
  abund_values = "counts",
  ...
)

\S4method{plotSeries}{SummarizedExperiment}(
  object,
  x,
  y = NULL,
  rank = NULL,
  colour_by = NULL,
  size_by = NULL,
  linetype_by = NULL,
  abund_values = "counts",
  ...
)
}
\arguments{
\item{object}{a
\code{\link[SummarizedExperiment:SummarizedExperiment-class]{SummarizedExperiment}}
object.}

\item{x}{a single character value for selecting the column from
\code{\link[SummarizedExperiment:SummarizedExperiment-class]{ColData}} that
will specify values of x-axis.}

\item{y}{a single character value for selecting the taxa from
\code{\link[SummarizedExperiment:SummarizedExperiment-class]{rownames}}.
This parameter specifies taxa whose abundances will be plotted.}

\item{rank}{a single character value defining a taxonomic rank, that is used
to agglomerate the data. Must be a value of \code{taxonomicRanks()}
function.}

\item{colour_by}{a single character value defining a taxonomic rank, that is used to
color plot. Must be a value of \code{taxonomicRanks()} function.}

\item{size_by}{a single character value defining a taxonomic rank, that is
used to divide taxa to different line size types. Must be a value of
\code{taxonomicRanks()} function.}

\item{linetype_by}{a single character value defining a taxonomic rank, that
is used to divide taxa to different line types. Must be a value of
\code{taxonomicRanks()} function.}

\item{abund_values}{a single character value for selecting the
\code{\link[SummarizedExperiment:SummarizedExperiment-class]{assay}} to be
plotted. (default: \code{abund_values = "counts"})}

\item{...}{additional parameters for plotting. See
\code{\link{mia-plot-args}} for more details}
}
\value{
A \code{ggplot2} object
}
\description{
This function plots series data.
}
\details{
This function creates series plot, where x-axis includes e.g. time points, and
y-axis abundances of selected taxa.
}
\examples{
library(mia)
object <- microbiomeDataSets::SilvermanAGutData()
# Plots 2 most abudant taxa, which are colore by their family
plotSeries(object,
           x = "DAY_ORDER",
           y = getTopTaxa(object, 2),
           colour_by = "Family")

# Counts relative abundances
object <- transformCounts(object, method = "relabundance")

# Selects taxa
taxa <- c("seq_1", "seq_2", "seq_3", "seq_4", "seq_5")

# Plots relative abundances of phylums
plotSeries(object[taxa,],
           x = "DAY_ORDER", 
           colour_by = "Family",
           linetype_by = "Phylum",
           abund_values = "relabundance")

# In addition to 'colour_by' and 'linetype_by', 'size_by' can also be used to group taxa.
plotSeries(object,
           x = "DAY_ORDER", 
           y = getTopTaxa(object, 5), 
           colour_by = "Family",
           size_by = "Phylum",
           abund_values = "counts")
}
\author{
Leo Lahti and Tuomas Borman. Contact: \url{microbiome.github.io}
}
